#
# spec file for package osinfo-db-tools
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           osinfo-db-tools
Version:        1.10.0
Release:        150500.1.1
Summary:        Tools for managing the osinfo database
License:        LGPL-2.1+ and GPL-2.0+
Group:          System/Management
Url:            https://releases.pagure.org/libosinfo/
Source:         https://releases.pagure.org/libosinfo/%{name}-%{version}.tar.xz
BuildRequires:  gettext-devel
BuildRequires:  glib2-devel
BuildRequires:  json-glib-devel
BuildRequires:  libarchive-devel
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  libxml2-devel >= 2.6.0
BuildRequires:  libxslt-devel >= 1.0.0
BuildRequires:  meson
#BuildRequires:  perl
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package provides tools for managing the osinfo database of
information about operating systems for use with virtualization

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install

%find_lang %{name}

%files -f %{name}.lang
%doc NEWS README
%{_bindir}/osinfo-db-export
%{_bindir}/osinfo-db-import
%{_bindir}/osinfo-db-path
%{_bindir}/osinfo-db-validate
%{_mandir}/man1/osinfo-db-export.1*
%{_mandir}/man1/osinfo-db-import.1*
%{_mandir}/man1/osinfo-db-path.1*
%{_mandir}/man1/osinfo-db-validate.1*

%changelog
* Tue Oct  4 2022 carnold@suse.com
- jsc#PED-2104 [Virt Tools] Refresh Virtualization Tools for Xen
  and KVM Management
* Tue Mar  1 2022 carnold@suse.com
- Update to version 1.10.0
  * Port to libsoup3 (optional)
  * Several CI improvements
  * Several translation improvements
* Mon Sep 27 2021 dimstar@opensuse.org
- BuildRequire pkgconfig(libsoup-2.4) instead of the package
  name libsoup-devel: with libsoup 3.0 appearing, the old version
  receives a compat-name (libsoup2).
* Tue Mar  2 2021 carnold@suse.com
- Update to version 1.9.0
  * Several CI improvements
  * Several translation improvements
  * Fix export/import tests
* Mon Jun  1 2020 carnold@suse.com
- Update to version 1.8.0
  * Several CI improvements
  * Several release scripts improvements
  * Several translations improvements
  * Several syntax-check improvements
* Mon Dec  2 2019 carnold@suse.com
- Update to version 1.7.0
  Changes in this release include:
  * Switch to meson build system
* Wed Nov 13 2019 carnold@suse.com
- Update to version 1.6.0
  Changes in this release include:
  * Refresh translations from zanata
  * spec,mingw: Add mingw*-libsoup as dependency
  * Commit 3917e5f4ae0e5 introduced libsoup dependency but forgot
    to add it to the mingw spec files.
* Thu May  9 2019 carnold@suse.com
- Update to version 1.5.0
  Changes in this release include:
  * Add a test suite covering all the tools
  * Improve usage of --root by not requiring its argument to end with '/'
  * Fix memory leak on osinfo-db-validate
  * Fix wording of osinfo-db-export --help
* Fri Mar  1 2019 carnold@suse.com
- Update to version 1.4.0
  Changes in this release include:
  * Refreshed translations from Zanata
  * Drop deprecated gnome-common and intltool
* Mon Feb  4 2019 carnold@suse.com
- Update to version 1.3.0
  Changes in this release include:
  * Avoid warnings on osinfo-db-export due to calling g_object_unref()
    on a NULL object
  * Improvements on osinfo-db-import manpage
  * Remove outdated FSF address from source file headers
  * Make osinfo-db-import capable to deal with URLs
  * Introduce osinfo-db-import --latest
  * Refreshed translations from zanata
* Wed Jun 20 2018 carnold@suse.com
- Update to version 1.2.0
  Changes in this release include
  * Don’t expand XML entities
  * Fix build with CLang
  * Don’t hardcode perl interpretor path
* Fri Jan 27 2017 jengelh@inai.de
- Use more appropriate RPM group
- Drop unnecessary %%__ macro indirections
* Thu Dec  1 2016 carnold@suse.com
- Update to version 1.1.0
  Changes in this release include
  * Add –license option to osinfo-db-export
  * Fix license file to refer to GPL, not LGPL
  * Fix typos in help output
  * List libarchive as pre-req in README
* Mon Oct 10 2016 carnold@suse.com
- Version 1.0.0
  libosinfo is a project providing information about operating systems,
  hypervisors and the (virtual) hardware devices they can support.
  This package contains a set of tools to assist administrators and
  developers in managing the database.
